package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````E!L``#0```"@H0````0`!30`(``)
M`"@`'0`<``$``'!@D0``8)$``&"1``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!,D@``3)(```4`````$```
M`0```*2=``"DK0``I*T``*0"``"X`@``!@`````0```"````K)T``*RM``"L
MK0``(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DI)T`
M`*2M``"DK0``7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`U\FVP//.0ZB!,\N5,>WKF@])>$($
M````$`````$```!'3E4```````0````#`````````&$```!K````````````
M``!9````00``````````````"````````````````````#D`````````2@``
M`#@```!D`````````"L```!0````40```#(```!A````9P````,````O````
M```````````C````1@```"T``````````````%(```!)````-@```$T```!>
M````:@```"$````'````"0`````````8`````````#\```!B````3P```#,`
M````````3````&,````U````#0```#H``````````````%H````Q````2```
M`$4````J````````````````````/0```$,````````````````````6````
M#P`````````^````(@```"<```````````````H```!'````-P```#L```!4
M`````````"X```!I````0`````````````````````````!5`````````$(`
M``!7````*`````8````D````2P``````````````````````````````````
M````````````````````````````````````````````````````````````
M$`````````!6````````````````````````````````````%```````````
M````6``````````<`````````&4```!H`````````!\``````````````!D`
M````````9@``````````````&P````X````@````)@````0````,````'@``
M`"P``````````````!T```!.``````````````!3````)0```%P````:````
M`````!<````+````````````````````6P```#`````\````$P```$0```!=
M````````````````````````````````````!0```````````````````#0`
M```````````````````1````````````````````*0```!4`````````$@``
M``````````````````````!?````````````````````8```````````````
M$0```$T````(````"`````&0$`0E0`2`*(``!:"&4(2`@0`""R@$C#B`$D&*
M```(30```$X```!1````50```%8```!?````8````&$`````````8P```&0`
M``!E````9@```&<```!J```````````````!KS3H;L7?'\[>1RUK?YI\+L6;
MMM1DU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_+%COEWFZXY)\
M^J%L8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````-`5`````````P`,````
M````L`````````,`&``3`@`````````````2````MP(`````````````$@``
M`&<``````````````!(````\`0`````````````2````!0(`````````````
M$@```$\"`````````````!(```">`@`````````````2````?P``````````
M````$@```/("`````````````!(````!```````````````@````L@$`````
M````````$@```.D"`````````````!(````_`@`````````````2````,@,`
M````````````$@```+```````````````!(```#.`0`````````````2````
M$```````````````(````,\"`````````````!(````,`@`````````````2
M````O`(`````````````$@`````"`````````````!(````U`0``````````
M```2````+```````````````(````"X!`````````````!(```"E`0``````
M```````2````P0(`````````````$@```-0``````````````!8```".`0``
M```````````2````!0,`````````````$@```'T!`````````````!(```#:
M`@`````````````2````$`$`````````````$@```%P!`````````````!(`
M``#6`0`````````````2`````@0`````````````$@```,4`````````````
M`!(````(`0`````````````1````.`(`````````````$@```#D#````````
M`````!$```#=`0`````````````2````J0(`````````````$@```&,!````
M`````````!(```"Y`0`````````````2````<`(`````````````$@```/@!
M`````````````!(```"7`@`````````````2````E@``````````````$@``
M`"H"`````````````!(```#``0`````````````2````;`$`````````````
M$@```"T!`````````````!(```!M```````````````2````6P(`````````
M````$@```)X!`````````````!(```"+`@`````````````2````IP``````
M````````$@````8!`````````````!$```#Q`0`````````````1````%@,`
M````````````$0```$0!`````````````!(````C`P`````````````1````
M3@$`````````````$@```/X``````````````!(```!R`0`````````````2
M````%P$`````````````$@```"4!`````````````!(```!\`@``````````
M```2````1@``````````````$@```.<``````````````!(```"^````````
M```````2````QP$`````````````$@```.P!`````````````!(````9`@``
M```````````2````6```````````````(@```%T$``!<L````````!``&0`+
M!```B$H``$`!```2``X`@@0``&Q```!0!P``$@`.`%,```#`&```U`(``!(`
M#@""`P``>#(```0````2``X`H`,``+Q'``#,`@``$@`.`#,$``!(L```````
M`!``&0"H!```?#(``(@"```2``X`:`0``$BP````````$``9`),#```$-0``
M,````!(`#@"V`P``*#P``*`````2``X`%P0``"!/```$````$0`0`$$$``!@
M3```6`$``!(`#@!,!```!#$``%@````2``X`5`0``%RP````````$``9`'T$
M``!<L````````!``&0"6!```(#\``$P!```2``X`OP0``,@\``!T````$@`.
M`"8$````L````````!``&`#:`P``-#4``+0!```2``X`CP0``$BP````````
M$``8`+4$``!$L```!````!$`&``L!```E!L````````2``X`=`0``,A+``"8
M````$@`.`"@$````L````````"``&`#P`P``_#X``"0````2``X`Q`,``%PQ
M```<`0``$@`.`.8#``"X30``3`$``!(`#@!<!```7+`````````0`!D`QP0`
M`.@V``!`!0``$@`.``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!A8F]R=`!?7W)E9VES=&5R7V%T
M9F]R:P!?7V%E86)I7W5N=VEN9%]C<'!?<'(P`%]?<W1A8VM?8VAK7V9A:6P`
M<F5A9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`
M4$Q?8W5R<F5N=%]C;VYT97AT`%]?865A8FE?=6YW:6YD7V-P<%]P<C$`<W1R
M;F-M<`!?7V5N=FER;VX`<W1R;&5N`%]?;65M;6]V95]C:&L`<F5A;&QO8P!L
M<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E861D:7(V-`!?7W-P<FEN=&9?8VAK
M`'5N;&EN:P!C;&]S961I<@!R;61I<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?
M9FQA9W,`8F]O=%]$>6YA3&]A9&5R`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R
M8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`;65M8W!Y`%]?=F9P
M<FEN=&9?8VAK`&5X:70`<W1D97)R`&QS965K-C0`<F5A9`!M96UC;7``9V5T
M=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N
M-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E
M<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U
M;@!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U
M;F1U;7``4$Q?;65M;W)Y7W=R87``;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`;&EB
M9V-C7W,N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T
M85]S=&%R=`!?7V)S<U]S=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N
M9%]?`%]?8G-S7V5N9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M0T-?,RXU`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U
M+C0R+C`O87)M=C9L+6QI;G5X+71H<F5A9"UM=6QT:2TV-&EN="]#3U)%````
M```````"``$``@`"``(``0`!``,``0`!``(``0`!``(``0`"``$``0`"``(`
M`@`"``$`!``"``$``0`!``$``0`!``(``@`"``(``0`"``(`!0`"``$``@`"
M``$``@`"``(``@`"``(`!``"``$``@`!``(``@`"``$``@`!``(``@`!``(`
M`@`!``8``P`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`8`,``!``
M```@````%&EI#0``!0#4!`````````$``0!T`P``$````"````!5)GD+```#
M`-X$`````````0`#`%8#```0`````````+21E@8```8`Y@0``!````"SD98&
M```$`/$$```0````%&EI#0```@#4!````````*2M```7````J*T``!<```#\
MKP``%P````2P```7````%+```!<````8L```%P```""P```7````)+```!<`
M```HL```%P```"RP```7````,+```!<````XL```%P```#RP```7````1+``
M`!<```#(KP``%0L``,RO```5#```T*\``!43``#4KP``%1D``-BO```3'0``
MW*\``!4>``#@KP``%1\``.2O```5)P``Z*\``!4I``#LKP``%3P``/"O```5
M/0``]*\``!4_``#XKP``%4P``-BN```6`P``W*X``!8$``#@K@``%@4``.2N
M```6!@``Z*X``!8'``#LK@``%@@``/"N```6"0``]*X``!8,``#XK@``%@T`
M`/RN```6#@```*\``!8/```$KP``%A````BO```6$0``#*\``!82```0KP``
M%A0``!2O```6%0``&*\``!86```<KP``%A<``""O```6&```)*\``!8:```H
MKP``%AL``"RO```6'```,*\``!8@```TKP``%B$``#BO```6(@``/*\``!8C
M``!`KP``%B0``$2O```6)0``2*\``!8F``!,KP``%B@``%"O```6*@``5*\`
M`!8K``!8KP``%BP``%RO```6+0``8*\``!8N``!DKP``%B\``&BO```6,```
M;*\``!8Q``!PKP``%C(``'2O```6,P``>*\``!8T``!\KP``%C4``("O```6
M-@``A*\``!8W``"(KP``%C@``(RO```6.0``D*\``!8Z``"4KP``%CX``)BO
M```60```G*\``!9!``"@KP``%D(``*2O```60P``J*\``!9$``"LKP``%D4`
M`+"O```61@``M*\``!9(``"XKP``%DD``+RO```62@``P*\``!9+``#$KP``
M%DP```A`+>E_`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7@F````,:/X@G*C.+@
M^+SE`,:/X@G*C.+8^+SE`,:/X@G*C.+0^+SE`,:/X@G*C.+(^+SE`,:/X@G*
MC.+`^+SE`,:/X@G*C.*X^+SE`,:/X@G*C.*P^+SE`,:/X@G*C.*H^+SE`,:/
MX@G*C.*@^+SE`,:/X@G*C.*8^+SE`,:/X@G*C.*0^+SE`,:/X@G*C.*(^+SE
M`,:/X@G*C.*`^+SE`,:/X@G*C.)X^+SE`,:/X@G*C.)P^+SE`,:/X@G*C.)H
M^+SE`,:/X@G*C.)@^+SE`,:/X@G*C.)8^+SE`,:/X@G*C.)0^+SE`,:/X@G*
MC.)(^+SE`,:/X@G*C.)`^+SE`,:/X@G*C.(X^+SE`,:/X@G*C.(P^+SE`,:/
MX@G*C.(H^+SE`,:/X@G*C.(@^+SE`,:/X@G*C.(8^+SE`,:/X@G*C.(0^+SE
M`,:/X@G*C.((^+SE`,:/X@G*C.(`^+SE`,:/X@G*C.+X][SE`,:/X@G*C.+P
M][SE`,:/X@G*C.+H][SE`,:/X@G*C.+@][SE`,:/X@G*C.+8][SE`,:/X@G*
MC.+0][SE`,:/X@G*C.+(][SE`,:/X@G*C.+`][SE`,:/X@G*C.*X][SE`,:/
MX@G*C.*P][SE`,:/X@G*C.*H][SE`,:/X@G*C.*@][SE`,:/X@G*C.*8][SE
M`,:/X@G*C.*0][SE`,:/X@G*C.*(][SE`,:/X@G*C.*`][SE`,:/X@G*C.)X
M][SE`,:/X@G*C.)P][SE`,:/X@G*C.)H][SE`,:/X@G*C.)@][SE`,:/X@G*
MC.)8][SE`,:/X@G*C.)0][SE`,:/X@G*C.)(][SE`,:/X@G*C.)`][SE`,:/
MX@G*C.(X][SE`,:/X@G*C.(P][SE`,:/X@G*C.(H][SE`,:/X@G*C.(@][SE
M`,:/X@G*C.(8][SE`,:/X@G*C.(0][SE`,:/X@G*C.((][SE`<J@XS!`+>D,
MP$W@R`^,Y63"G^4LT$WB8#*?Y1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-XA0@
MC>(<`(WB0$*?Y0`PD^4D,(WE`#"@X];__^LP(I_E!$"/X`(@E.<H,I_E#""-
MY0,PE.<"$*#A`P"@X1`PC>5R#0#K$#*?Y0,PE.<`,-/E``!3XU$```IP+QWN
M_#&?Y1P0G>4#,)_G!`"!X@,@DN<'`7#CSC/2Y0,P@^/.,\+E9```B@`!H.$#
M4('BH?__ZP`PH.'($9_ER"&?Y0$0C^``X)'E`B"/X!@0G>6XP9_EN`&?Y00P
M@N4<()WE`$"1Y0S`C^```(_@`0!2XQ!0@^@,`(/E5@``V@3@0>(,`(/B`N&.
MX`3`L>4!`%[A!,"@Y?O__QH#P(+B`."@XW!!G^5P$9_E!$"/X`P`E.4,X8/G
M!2"@X0$0C^``X(WE"/__ZP``4.,L```*3$&?Y01`C^`,`)3E3?__ZP!0H.$\
M`9_E(!"-X@``C^`,$(WE)`0`ZP``4.,,$)WE(@``"B`QG^4#,(_@#`"3Y>;^
M_^LA___K$"&?Y=`PG^4"((_@`S"2YP`@D^4D,)WE`B`SX``PH.,K```:!0"@
MX2S0C>(P@+WH##"-Y?[^_^O<()_E``!0XP(@C^`,`(+E'P``"A/__^MP+QWN
MQ!"?Y0PPG>4!$)_G`1"2YW8VP>6?___J#`"4Y>#^_^O/___J"`"4Y0``4.,!
M```*Y@L`Z]?__^J0`)_E``"/X/8#`.L``%#C"`"$Y='__PKV___J>#"?Y7@`
MG^4#,)3G``"/X`,0H.$,,(WE,O__ZP3`H..N___J`0"@XUC__^L;___KW)4`
M`!P!``"PE0``_````!0!```D`0``>)8``*R6``"LE@``&#D``!@Y``!,E@``
M2!8``"26```X-@``\)4``%B4``"@E0``$)4``!@U```H`0``]#8```"PH.,`
MX*#C!!"=Y`T@H.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``
MFN<J___KC?[_Z_R2```P`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!D_[_
MZN22`````0``+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E
M`C"3YP``4^,>_R\!$_\OX3R4```XE```L)(```0!```X`)_E.#"?Y0``C^`#
M,(_@`#!#X*,?H.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_
M+P$3_R_A^),``/23``!@D@``"`$``%@PG^58()_E`S"/X``PT^4"((_@``!3
MXQ[_+Q$!RJ#C$$`MZ0S`3>#X#XSE-#"?Y0,PDN<``%/C`@``"B@PG^4#`)_G
M]O[_Z\?__^L!(*#C&#"?Y0,PC^``(,/E$("]Z*B3```DD@``+`$``"R3``!<
MDP``S?__Z@'*H./P3RWI#,!-X"@-C.5D+)_E9#R?Y0(@C^`#,)+G`!"@X:W?
M3>(`,)/EK#*-Y0`PH.,`4*#C*""-XD``@.*`8('B!,`0Y0C@$.4L-*#A_SP#
MXBP\@^$,1*#A##R#X?](!.((`(#B/L^_Y@0P@^$``%;A`,""Y010@N4(,(+E
M#%""Y1`@@N+M__\:H#"=Y3"PG>600)WE*%"=Y30@G>68<)WE##"-Y10PC>4C
M/HWB"Z"@X00@C>4<L(WE)!"-Y06`H.$$L*#A+)"=Y:3@G>6<8)WEE""=Y0P0
MG>40<(WE,`"-X@@PC>480(WE(%"-Y0$``.H%H*#A!$"-Y0!`H.,!,*#A/,"0
MY3@0D.4(4+#E=$"`Y01`D.4%$"'@"Q`AX`3`+.`($"'@`L`LX`G`+.`'L*#A
M`W"@X:$_H.&,,(/A`1"1X`,0@>$(,)WE!B"@X0,`4.$.8*#A"H"@X0#@H.,$
MD)WE<!"`Y>'__QHD$)WE##N?Y0!@D>4@4)WE!`"1Y0B@D>4@P)'E`R"5X*9=
MH.$0<)'E&)"1Y0S@D>6`4H7A#""2X(92A>$JP:#A`E"5X`[/C.$)("?@"L^,
MX1RPG>4*(`+@)H&@X0D@(N``CXCA#``GX`)0E>`&``#@`R";X`D@DN`'`"#@
M!H^(X0(`D.`X()WE".`LX`,@DN`%X`[@#.`NX`<@DN#E#8#@#B"2X.#M@N!`
M()WE&$"=Y0,@DN`,()+@9<$HX`#`#.`(P"S@#""2X$C`G>5@`:#A`\"<X`C`
MG.!E@2#@#H`(X&6!*.#N+8+@","<X.*-C.!0P)WE`\"<X&7!C.!N42#@`E`%
MX`!0)>`%P)S@6%"=Y6(AH.$#4)7@``"5X&Y1(N`(4`7@;E$EX.C-C.`%`)#@
M[%V`X&``G>4#`)#@;@&`X&CA(N`,X`[@`N`NX`X`D.!HX)WE;,&@X0/@GN`"
M()[@:.$LX`7@#N!HX2[@Y0V`X`X@DN#@[8+@<""=Y0,@DN!H(8+@98$LX`"`
M".`,@"C@"""2X.Z-@N!X()WE8`&@X0,@DN`,()+@9<$@X`[`#.!EP2S@#""2
MX.C-@N"`()WE`R"2X&4A@N!N42#@"%`%X`!0)>`%()+@[%V"X(@@G>5H@:#A
M`R"2X```DN!N(2C@#"`"X&XA(N`"()#@`P"4X&X!@.#E[8+@;"$HX`4@`N`(
M("+@95&@X0`@DN`0`)WE[DV"X&PA)>`#`)#@#B`"X`@`D.!L(2+@`""2X!0`
MG>7D+8+@`P"0X&S!@.!N`27@!```X`4`(.`,`)#@XLV`X*@`G>5D0:#A`P"0
MX`4`D.!N423@`E`%X&Y1)>`%`)#@[%V`X+``G>70@)WE`P"0X&X!@.!BX23@
M#.`.X`3@+N`.X)#@N`"=Y6S!H.$#`)#@!`"0X&)!+.`%0`3@8D$DX`0`D.#`
M0)WEY>V.X`,PE.!B,8/@92$LX`X@`N`,("+@[@V`X`(PD^#@+8/@R$"=Y20X
MG^5NX:#A`T"4X`Q`E.!EP2[@`,`LX`S`E.`#0)C@94&$X-B`G>7B78S@8,$N
MX`+`+.`,P)3@8B&@X0-`F.`.0)3@X("=Y6#A(N`%X"[@#N"4X`-`F.#ES8S@
MZ("=Y6!!A.!E`2+@#``@X.SMCN```)3@;,&@X0-`F.`"0)3@\("=Y64A+.`.
M("+@[@V`X`(@E.`#0)C@94&$X/B`G>7@78+@;B$LX``@(N`"()3@8`&@X0-`
MF.`,0)3@`(&=Y6[!(.`%P"S@Y2V"X`S`E.`#@)C@XDV,X&[AB.!EP2#@"(&=
MY0+`+.`,P)[@8B&@X0/@F.``X)[@$(&=Y64!(N`$`"#@Y,V,X```GN`#X)C@
M9>&.X!B!G>7L78#@9`$BX`P`(.```)[@;,&@X0/@F.`"X)[@((&=Y60A+.`%
M("+@Y0V`X`(@GN`#X)C@9.&.X"B!G>7@38+@92$LX``@(N`"()[@8`&@X0/@
MF.`,X)[@,(&=Y67!(.`$P"S@Y"V"X`S`GN`#X)C@9>&.X#B!G>7B78S@9,$@
MX`+`+.!B(:#A0+&=Y0S`GN`#@)C@9.$BX```F.`%X"[@Y<V,X`[@D.`#`)O@
M[(V.X&0!@.!EX2+@2$&=Y0S@+N`.X)#@;,&@X0,`E.`"`)#@4$&=Y>@MCN!E
MX2S@".`NX`[@D.`#`)3@90&`X&A!+.!849WE`D`DX.+MCN`$`)#@8B&@X0-0
ME>`,P)7@:$$BX&!1G>4.0"3@!$"<X`/`E>#N#8#@[#6?Y6BQG>5HP8S@;H$B
MX&!1H.$`@"C@X$V$X`B`G.`#`)O@;L&%X0(`D.!PL9WEY"V(X`3`#.!N@07@
M",",X0S`D.`#L)O@9`&%X62!!>!NX8O@`@``X'BQG>4(`(#AXLV,X`X`D.!B
M(:#A`^";X`7@GN!D48+A9($"X("QG>4,4`7@"%"%X0[@E>`#4)O@[`V`X&11
MA>!L08+A;($"X(BQG>4`0`3@"$"$X>#MCN`%4)3@8`&@X0-`F^`"0)3@[BV%
MX&Q1@.%L@0#@D+&=Y0Y0!>`(4(7A!$"5X`-0F^!L487@;L&`X6Z!`."8L9WE
M`L`,X`C`C.'B383@!5"<X&(AH.$#P)O@`,"<X.0-A>!N48+A;H$"X*"QG>4$
M4`7@"%"%X0S`E>`#4)O@;E&%X&3A@N%D@0+@J+&=Y0#@#N`(X([AX,V,X`50
MGN!@`:#A`^";X`+@GN#L+87@9%&`X62!`."PL9WE#%`%X`A0A>$.X)7@`U";
MX&11A>!L08#A;($`X+BQG>4"0`3@"$"$X>+MCN`%4)3@8B&@X0-`F^``0)3@
M[@V%X&Q1@N%L@0+@P+&=Y0Y0!>`(4(7A!$"5X`-0F^!L487@;L&"X6Z!`N#(
ML9WE`,`,X`C`C.'@383@!5"<X&`!H.$#P)O@`L"<X.0MA>!N48#A;H$`X-"Q
MG>4$4`7@"%"%X0S`E>`#4)O@;E&%X&3A@.%D@0#@V+&=Y0+@#N`(X([AXLV,
MX`50GN!B(:#A`^";X`#@GN#L#87@9%&"X62!`N#@L9WE#%`%X`A0A>$.X)7@
M`U";X&11A>!L08+AZ+&=Y6R!`N``0`3@"$"$X>#MCN`%4)3@8`&@X0-`F^`"
M0)3@[BV%X&Q1@.%L@0#@\+&=Y0Y0!>`(4(7A!$"5X`-0F^!L487@;L&`X6Z!
M`.#XL9WE`L`,X.)-A.`(P(SA8B&@X07`G.`#L)O@;E&"X6Z!`N```)O@!%`%
MX`"RG>4(4(7AY,V,X```E>`#4)O@;E&%X.SM@.!D`8+A\#*?Y62!`N`(LIWE
M#```X`@`@.%LP:#A!0"0X`-0F^`0@IWE`E"5X&0A+.`.("+@`B"5X`-0F.``
M@*#C[@V`X&11A>`$@('EX$V"X`R`@>48(IWE%("!Y1R`@>4D@('E;H$LX`"`
M*.`(4)7@8`&@X0,@DN`@@IWE#""2X&[!(.`$P"S@#,"2X`,@F.#D787@9($@
MX&XA@N`HXIWE!8`HX.7-C.`(()+@95&@X0/@GN`P@IWE``">X&3A)>`,X"[@
M#N"0X`,`F.#L+8+@;($EX&0!@.`X0IWE`H`HX.+MCN`(`)#@8B&@X0-`E.!L
M@2+@!4"4X$!2G>4.@"C@"$"4X`-0E>#N#8#@;H$BX&Q1A>!(PIWE`(`HX.!-
MA.`(4)7@8`&@X0/`G.!N@2#@`L"<X.0MA>!04IWE!(`HX`C`G.`#4)7@9($@
MX&Y1A>!8XIWE`H`HX.+-C.`(4)7@8B&@X0/@GN!D@2+@`.">X.P-A>!@4IWE
M#(`HX`C@GN`#4)7@;($BX&11A>!H0IWE`(`HX.#MCN`(4)7@8`&@X0-`E.!L
M@2#@`D"4X.XMA>!P4IWE#H`HX`A`E.`#4)7@>(*=Y6S!A>#B783@;D$@X`)`
M).`$P)S@8D&@X0,@F.``()+@@(*=Y>4-C.!NP23@!<`LX`S`DN`#()C@;B&"
MX(B"G>5EX23@`.`NX.#-C.`.()+@8.&@X0,`F.`$`)#@98$NX)!"G>4,@"C@
M["V"X`@`D.`#0)3@;($NX&5!A.`"@"C@X@V`X)A2G>4(0)3@X$V$X&(AH.$#
M4)7@9'&'X`Y0E>`0<('EH.*=Y6QQ(N``<"?@!U"5X`,PGN!@D8G@!C"3X&`!
M(N!L,8/@!``@X.1=A>``,)/@Y3V#X!B0@>4`,('E(#"1Y0I0E>`#()+@(""!
MY40@G^4L,)_E`B"/X`A0@>4#,)+G`""3Y:PRG>4"(#/@`#"@XP$``!JMWXWB
M\(^]Z(G[_^NDD0``'`$``)EY@EJAZ]ENW+P;C];!8LILA0```<J@X_!`+>D,
MP$W@``",Y2@`#.4!<*#A_!"?Y0':3>+X,)_E%-!-X@$0C^`#,)'G`&"@X0$*
MC>(`,)/E##"`Y0`PH.,,`(#BU`"?Y=0@G^4,$(WB``"/X(;[_^L`,%#B!@``
MV@$@0^("0(W@#!#4Y0``4>,7```:``!2XQ0``!IP#QWNH#"?Y0<@H.$#,)_G
M!A"@X0,`D.<0^__KC""?Y7@PG^4"((_@`1J-X@,PDN<,$('B`""3Y0`PD>4"
M(#/@`#"@XQ,``!H!VHWB%-"-XO"`O>@",*#A`R"@X2\0H.,,`(WB!#"-Y7W[
M_^L``%#CXO__"G#/'>XT`)_E!A"@X0``G^<$,)WE``"<YPP@C>(B^__KX/__
MZCO[_^O\A```'`$``+@E``#_#P``I(4``("$```PA0```<J@X_!'+>D,P$W@
MX`^,Y;PPG^6\()_E`S"/X`(@D^<`@)+E``!8XR<```H`4-#E``!5XST`51,!
M4*`3`%"@`Q,``!H`0)CE``!4XPX```H!D*#A`'"@X0A@H.$%(*#A!Q"@X00`
MH.$]^__K``!0XP(``!H%,-3G/0!3XPL```H$0+;E``!4X_/__QH$`*#A\(>]
MZ`!0H.$!,/7E``!3XST`4Q/[__\:`%!%X.3__^H(8$;@`5"%XD9AH.$%0(3@
M!`"@X0!@B>7PA[WH"$"@X>W__^K4@P``&`$```'*H./P0RWI#,!-X-`/C.4!
M0*#A)"*?Y20RG^4"((_@`S"2YQ303>(`,)/E##"-Y0`PH.,`,-'E`%"@X3T`
M4^,!0($"!`"@X</Z_^L($(WB`&"@X04`H.&Q___KY'&?Y0"`4.('<(_@0@``
M"KKZ_^L``%;A.0``FLPQG^4(()WE`W"7YP(AH.$``-7E``!0XST`4!,!`*`3
M``"@`P4```H%`*#A`3#PY0``4^,]`%,3^___&@4`0.`"8(;B``"&X``@C>4`
M8)?EQ_K_ZP`@G>4``%#C`@"&YQ4```H`,-7E`!"7Y3T`4^,``%,3`A"1YP`P
MP>4'```*`0"%X@$@@>(!,-#D`A"@X0``4^,]`%,3`3#"Y/G__QH],*#C`2"@
MX0`PP>4!,-3D``!3XP$PXN7[__\:%"&?Y00QG^4"((_@`S"2YP`@D^4,,)WE
M`B`SX``PH.,X```:%-"-XO"#O>@!@$CB`3#4Y```4^,!,.CE^___&N[__^K,
M,)_E`W"7YP`@E^4`,)+E``!3XR<```H",*#A!!"SY0@`H.$``%'C`8"(XOK_
M_QH#`(#B`#&@X9P0G^4!$(_@``"1Y0``4.,2```:`0"@XP``@>4#`*#A!""-
MY0`PC>6#^O_K`)!0XM/__PH((:#A`#"=Y000G>4`((WEJ?K_ZP`@G>4`D(?E
M`#"@XP&`B.((,8GGG?__Z@,0H.$"`*#AH_K_ZP"04.(``(?EPO__"@@AH.'S
M___J`X"@X0@PH./<___J;?K_Z_2"```<`0``K((``!@!``#4@0``W((```'*
MH.,00"WI#,!-X(@/C.6,()_EC#"?Y0(@C^!PT$WB`S"2YPT0H.$`0*#A`#"3
MY6PPC>4`,*#C9/K_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,*```*
M2""?Y4`PG^4"((_@`S"2YP`@D^5L,)WE`B`SX``PH.,'```:<-"-XA"`O>@"
M$*#C!`"@X0GZ_^L0#V_AH`*@X>[__^H^^O_KH(```!P!``!4@````<J@XW!`
M+>D,P$W@<`^,Y70AG^5T,9_E`B"/X`,PDN>`T$WB`%!0X@`PD^5\,(WE`#"@
MXP(```H`,-7E``!3XPH``!I((9_E0#&?Y0(@C^`#,)+G`""3Y7PPG>4"(#/@
M`#"@XT<``!J`T(WB<("]Z+CY_^L`0%#B\?__"@0`H.$X^O_K``!0XS````H3
M(-#E$S"`XBX`4N,"```:`2#3Y0``4N/T__\*$R#0Y2X`4N,K```*!0"@X0@P
MC>7D^?_K"#"=Y0!@H.$#`*#A##"-Y=_Y_^L`((;@`B""X@(`H.$(((WE_OG_
MZP!@H.$,,)WE`A"@XP0PC>68,)_E"""=Y0,PC^``4(WE&?K_ZP8`H.$0$(WB
MO_G_ZP$`<.,&`*#A`P``"B`PG>4/.@/B`0E3XQ(```K)^?_K!@"@X:SY_^L$
M`*#A!_K_ZP``4./.__\:!`"@X=;Y_^L%`*#A[/G_Z[?__^H!(-/E+@!2X]#_
M_QH"(-/E``!2X[___PK,___JGO__Z^O__^K8^?_K\'\``!P!``"\?P```"``
M``'*H.,00"WI#,!-X.@/C.5P3QWN;!"?Y6PPG^4!$(_@`S"1YQ#03>)@`)_E
M##"-Y0,@H.$``)_G5#"?Y500G^4``)3G`S"/X`$0C^#G^?_K`,"@XT``G^5`
M,)_E``"?YSP@G^4\$)_E`S"/X```E.<"((_@"!"-Z`$0C^"'^?_K$-"-XA"`
MO>A0?@``$`$``$1_``#07P``)!\``!Q_```((@``[!8``!`?```\$)_E/#"?
MY0$0C^`#,)'G<!\=[@,@H.$(T$WB*`"?Y00PC>4``)_G(#"?Y0``D><<$)_E
M`S"/X`$0C^`(T(WBO_G_ZKA]```0`0``J'X``#1?``"('@```<J@XW!`+>D,
MP$W@``",Y0'*3.(``(SE,``,Y>`@G^4"VDWBW#"?Y2#03>("((_@`S"2YP(:
MC>(<$('B`#"3Y0`P@>4`,*#CE?G_Z[C`G^6X,)_E#,"/X`$0C>@!"HWB`A"@
MXZ@@G^4#,(_@&`"`XI?Y_^L!"HWB`2J@XQ00C>(8`(#BC/G_ZP!`4.(`4*"S
M"P``N@$PA.(#`*#A##"-Y6?Y_^L`4%#B!0``"@PPG>4$(*#A%!"-XC'Y_^L`
M,*#C!##%YTP@G^4X,)_E`B"/X`(:C>(#,)+G'!"!X@`@D^4`,)'E`B`SX``P
MH.,#```:!0"@X0+:C>(@T(WB<("]Z%+Y_^L\?0``'`$``%0>```T'@```1``
M`)Q\``"W___J`<J@X_!/+>D,P$W@``",Y:@`#.4\(I_E0MU-XC@RG^4$T$WB
M`B"/X`!0H.$L`I_E`S"2YT'-C>(!<*#A``"/X!`0C>(\P(SB`#"3Y0`PC.4`
M,*#C`/[_ZR\0H.,`0*#A!0"@X=KX_^L``%#C$@``"NP!G^4%$*#A``"/X"W^
M_^L%`*#AW"&?Y<PQG^4"((_@01V-X@,PDN<\$('B`""3Y0`PD>4"(#/@`#"@
MXV@``!I"W8WB!-"-XO"/O>@'`*#A#OG_ZZ`1G^4!$(_@'?G_ZP"04.+E__\*
M`##9Y8RQG^4``%/C"["/X"D```H``%3C!```"@D0H.$$`*#A1/G_ZP``4.,9
M```*"0"@X>#X_^L!,$#B`S")X`,`6>$`H*#A`3"#,@``H#,!$(DR`P``.@@`
M`.H#`%'A``##Y0(```H!('/E+P!2X_G__PH)`*#AS_C_ZP"@H.$%`*#AS/C_
MZPH`@.`"`(#B`0I0XQ4``#K\$)_E``"@XP$0C^#Q^/_K`)!0XKG__PH`,-GE
M``!3X]7__QH``%3C*0``"@`PU.4N`%/C`P``"LB0G^4!H*#C"9"/X.?__^H!
M,-3E``!3X^K__PKW___JK""?Y0LPH.$"((_@`A"@XP0@C>4`D(WE`2J@XPA0
MC>5\`(WB\/C_ZQ`0C>)\`(WBEOC_ZP``4./:__\:(#"=Y0\Z`^(""5/CUO__
M&@$0H.-\`(WBBOC_ZP``4./1__\:4`"?Y7P0C>(``(_@O_W_ZWP`C>*O^/_K
MC___ZCB0G^4!H*#C"9"/X,#__^JU^/_K)'P``!P!``!4'0``)!T``+Q[``#D
M'```S!P``#0<``#<&P``Z!L``&P;``!`&P```<J@XQ!`+>D,P$W@^`^,Y2\0
MH.,`0*#A6OC_ZP``4.,!0(`2!`"@X1!`O>B1^/_J`<J@XQ!`+>D,P$W@``",
MY1@`#.5\(9_E`=I-XG@QG^40T$WB`B"/X`$:C>(#,)+G#!"!X@`PD^4`,('E
M`#"@XP`04.(Q```*`##1Y0``4^,N```*!!"-Y5_X_^L!((#B`0I2XSH``(H,
M0(WB!!"=Y00`C>4$`*#A7?C_ZP0PG>4!,$/B`S"$X`0`4^$'``":`!"@XP(`
M`.H!$$/D`P!4X0(```H`(-/E+P!2X_G__PHO$*#C!`"@X2;X_^L``%#C)0``
M"@0`4.$`,*"#`##`A00`H.%;^/_KP""?Y;@PG^4"((_@`1J-X@,PDN<,$('B
M`""3Y0`PD>4"(#/@`#"@XR,``!H!VHWB$-"-XA"`O>B,()_E@#"?Y0(@C^`!
M&HWB`S"2YPP0@>(`()/E`#"1Y0(@,^``,*#C%0``&F0`G^4``(_@`=J-XA#0
MC>(00+WH//C_Z@``H./>___J2""?Y30PG^4"((_@`1J-X@,PDN<,$('B`""3
MY0`PD>4"(#/@`#"@XP(``!H@`)_E``"/X.O__^HW^/_K;'D``!P!``"P>```
M>'@``)09```L>```2!D```'*H.-P0"WI#,!-X.@/C.7`))_EP#2?Y0(@C^"\
M5)_E`S"2Y[ADG^4(T$WB!5"/X``PD^4$,(WE`#"@XP9@C^`-$*#A!@"@X>C\
M_^L``%#C#@``"HPTG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__
M"@0P@^($()/E``!2XP0@@^3[__\:Z___ZE1DG^4&8(_@#1"@X08`H.'2_/_K
M``!0XPX```HT-)_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$
M,(/B!""3Y0``4N,$((/D^___&NO__^H`9)_E!F"/X`T0H.$&`*#AO/S_ZP``
M4.,.```*W#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#
MX@0@D^4``%+C!""#Y/O__QKK___JK&.?Y09@C^`-$*#A!@"@X:;\_^L``%#C
M#@``"H0SG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($
M()/E``!2XP0@@^3[__\:Z___ZEACG^4&8(_@#1"@X08`H.&0_/_K``!0XPX`
M``HL,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3
MY0``4N,$((/D^___&NO__^H$8Y_E!F"/X`T0H.$&`*#A>OS_ZP``4.,.```*
MU#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4`
M`%+C!""#Y/O__QKK___JL&*?Y09@C^`-$*#A!@"@X63\_^L``%#C#@``"GPR
MG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2
MXP0@@^3[__\:Z___ZEQBG^4&8(_@#1"@X08`H.%._/_K``!0XPX```HD,I_E
M`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$
M((/D^___&NO__^H(8I_E!F"/X`T0H.$&`*#A./S_ZP``4.,.```*S#&?Y0`0
MG>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#
MY/O__QKK___JM&&?Y09@C^`-$*#A!@"@X2+\_^L``%#C#@``"G0QG^4`$)WE
M`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[
M__\:Z___ZF!AG^4&8(_@#1"@X08`H.$,_/_K``!0XPX```H<,9_E`!"=Y0,P
ME><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___
M&NO__^H,`9_E#1"@X0``C^#W^__K`!!0X@(```KX`)_E``"/X"G\_^OP`)_E
M#1"@X0``C^#N^__K`!!0X@(```K<`)_E``"/X"#\_^O4`)_E#1"@X0``C^#E
M^__K`!!0XA(```K``)_E``"/X!?\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00P
MG>4"(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>@'_/_JA`"?
MY0T0H.$``(_@S/O_ZP`04.+I__\*<`"?Y0``C^#^^__KY?__ZOKV_^O$=P``
M'`$``+!W```4&0``&`$``,@8``!X&```+!@``-P7``"4%P``V!8``/`6``"D
M%@``6!8``(05``"P%0``A!4``*`5``"@%0``G!4``,`4``!H<P``>!4``-P4
M``!(%0``S!0```'*H.,$X"WE#,!-X/`/C.5X()_E>#"?Y0(@C^!T`)_E#-!-
MX@,PDN<-$*#A``"/X``PD^4$,(WE`#"@XYO[_^L``%#C!0``"@``T.4``%#C
M,`!0$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C`0``&@S0C>($\)WDO/;_ZX1R```<`0``*!0``#1R```!RJ#C#P`MZ03@
M+>4,P$W@\`^,Y4@@G^5(,)_E`B"/X`,PDN<,T$WB`#"3Y00PC>4`,*#C,`"?
MY3#`G^44,(WB``"/X``PC>4,`)#G`A"@XQ`@G>4``)#EC/;_Z_\`H./;]O_K
MX'$``!P!``"\<0``(`$```#`H./P0RWI`>B@XPS`3>`.X$S@`<I,X@``C.4.
M`%SA^___&C@`#N4"$*#C<.&?Y0'83>)LP9_E'-!-X@[@C^`,P)[G`4B-X@`@
MH.,`,*#C`,"<Y13`A.4`P*#C`!"-Y0"`H.%[]O_K`0!0X@!PP>+'+Z#AQS\@
MX`(P4^!S,/_F`C`CX`(P4^`"(,+@`V!0X`)PQ^```%?C%$"$XC8``+H,4(WB
M`!"@XP8@H.$',*#A"`"@X0`0C>5F]O_K`0!QXP$`<`,R```*!1"@X0@`H.'4
M()_E*?;_ZP$`<.,I```*!P!0XQ\``)H(`$#B`$"5X!P``"JTD)_E"9"/X`(`
M`.H!0$3B!0!4X18``#H((*#C"1"@X00`H.'Q]?_K``!0X_;__QH%0$3@!@"4
MX,0?I^!\()_E;#"?Y0(@C^`!R(WB`S"2YQ3`C.(`()/E`#"<Y0(@,^``,*#C
M$```&@'8C>(<T(WB\(.]Z`%H5N(`<,?B`0!WXP$(=@/)__\:``#@XP`0H.'I
M___J*`"?Y0``C^!]___K(`"?Y0``C^!Z___K,O;_ZTQQ```<`0``"``!`,QQ
M``!0<```1!(``"@2```!RJ#C$$`MZ0S`3>#X#XSEY/7_ZP?V_^L``%#C``"0
M%1"`O>@!RJ#C<$`MZ0S`3>#0#XSE%"&?Y11!G^44,9_E`B"/X`,PDN<@T$WB
M!$"/X`!0H.$$`*#A&!"-X@`PD^4<,(WE`#"@X]OZ_^L`,%#B`@``"@`@T^4`
M`%+C#@``&M0@G^7,,)_E`B"/X`,PDN<`()/E'#"=Y0(@,^``,*#C*0``&@40
MH.&P`)_E``"/X"#0C>)P0+WH_OK_Z@4`H.$0,(WETO7_ZQ`PG>4`8*#A`P"@
MX10PC>7-]?_K`""&X`(@@N("`*#A$""-Y>SU_^L4,)WE:!"?Y0@PC>5D,)_E
M`1"/X!`@G>4#,(_@!!"-Y0!0C>4"$*#C`&"@X03V_^M$()_E+#"?Y0(@C^`#
M,)+G`""3Y1PPG>4"(#/@`#"@XP80H`$$`*`!V/__"M?U_^N(;P``T!$``!P!
M``!`;P``<!$``"P0```H$```H&X```'*H./P3RWI#,!-X.@.C.6L%I_E]-!-
MXJC&G^6H)I_E&`"-Y0$0C^`"()'G#,"/X`PPC.(88(SBG$"-XJC@C>(`()+E
M[""-Y0`@H.,'`)/H!P"$Z`\`MN@/`*[H`P"6Z##`C.*04(WB`P".Z`<`G.@'
M`(7H5`:?Y2!PC>('$*#A``"/X'CZ_^M$II_E`&!0X@J@C^`"```*`##6Y0``
M4^,@`0`:8_7_ZX;U_^L``%#C>P``"@!@D.4``%;C>```"@8`H.%V]?_K@""@
MX0&P@N(+`*#AEO7_ZP#`UN4`4*#A``!<XPN`H!$<`(T5&P$`"N"5G^4)D(_@
M"R"@X0DPH.$"$*#C!0"@X0#`C>6L]?_K"P!8X0@@H"$+(*`Q`C!+X@L00N`!
MP/;E`A"!X@(P0^`"`%'A`;"#(`*P@S```%SC`E"%XNO__QJ,!9_EJ&"-X@``
MC^`"``#J!`"VY0``4.-?```*!Q"@X3_Z_^L`4%#B^/__"@`PU>4``%/C]?__
M"@;[_^L``%#C\O__"@4`H.%>]?_K`%!0XE$```H%`*#A/_7_ZQQ`G>4`8*#A
M!`"@X3OU_^L`8(;@`6N&X@1@AN(&`*#A6O7_ZP"`H.$,-9_E!B"@X0,PC^`(
M,(WE`#6?Y0(0H.,#,(_@!#"-Y?0TG^4,0(WE`S"/X`!0C>5P]?_K!QV@XP@`
MH.'=]/_K`0!PXP,``!J(]?_K`,"0Y1$`7..U```:!Q"@X0@`H.%/]?_K`$!0
MXC4```JL-)_E`A"@XP,@FN<8,)WE``"2Y9PDG^4`,)/E`B"/X`"`C>4Z]?_K
M`%"@XX@DG^5<-)_E`B"/X`,PDN<`()/E[#"=Y0(@,^``,*#C"@$`&@4`H.'T
MT(WB\(^]Z!WU_^L`8%#BD@``&@10A>(``)7E``!0XZT```H'$*#A[/G_ZP`P
M4.+W__\*`##3Y0``4^/T__\*\/__Z@4`H.$-]?_K`%!0XJ[__QH$0(3B`%"4
MY0``5>.J__\*`##5Y0``4^-Y```*!0"@X:;Z_^L``%#C]/__"N___^HP,)WE
M#SH#X@$)4^/%__\:.%"=Y</T_^L``%7AP?__&C`PG>6#.Z#AHSN@X0<-4^.\
M__\:!@"@X?GT_^L`4*#AH`.?Y0<0H.$``(_@POG_ZP`04.*)```*&#"=Y0``
MD^6F^__K`)!0XH0```H)`*#AQ_3_ZP,`4.,`H*#A#```FF03G^4$`$#B``")
MX`$0C^`?]?_K``!0XP4``!H$`%KCKP``"@J@B>`%,%KE+P!3XZL```HT`Y_E
M!Q"@X0``C^"E^?_K``!0XP,```H`,-#E,`!3XP``4Q,$```:"0"@X0`0H..Y
M]/_K`'!0XF8``!K\$I_E_`*?Y0$0C^```(_@S/G_Z][T_^OL,I_E["*?Y0,P
MC^`$,(WEY#*?Y0(@C^#@HI_EX)*?Y>!RG^4(`(WE#""-Y0(0H.,&(*#A!0"@
MX0"`C>4#,(_@V?3_ZPJ@C^`)D(_@!W"/X`\``.KR]/_K`#"0Y1$`4^,0```:
MQ/3_ZP#`H.$!0(3B`A"@XPHPH.$&(*#A!0"@X8`0C>D0D(WE#$"-Y0"`C>7%
M]/_K!QV@XP4`H.$R]/_K`0!PX^K__PH(`*#A7O3_ZU0"G^4%$*#A``"/X)OY
M_^L%`*#A=/[_ZU___^H#4*#A*___ZFST_^N`(*#A`;""XO3^_^KH(9_E&#"=
MY0(@FN<`,)/E``"2Y1`BG^4"$*#C`!&-Z`(@C^")]/_K3?__ZF'^_^OX(9_E
ME#&?Y0(@C^`#,)+G`""3Y>PPG>4"(#/@`#"@XU@``!H&`*#A]-"-XO!/O>AK
M]/_J'`"-Y??^_^H-`*#C</3_ZPV`H..T89_E4\"@XP!0H.$(L*#A!F"/X!P`
MC>77_O_J&#"=Y0"0D^5W___JR_W_ZP"04>(`H*#AE/__N@"PH.,*(%#B`##)
MX@<`H.$`L(WE6/3_ZX@0C>(&(*#C!P"@X1@0C>4=]/_K!@!0XQ@0G>4T```:
M2#&?Y8@@G>4#`%+A@O__&K0@T>$X,9_E`P!2X7[__QHR(%KB`##)X@<`H.$`
ML(WEP$"-XD+T_^LH(*#C!P"@X000H.$(]/_K*`!0XR```!H`,9_E`!&?Y0,P
MC^`$,(WE^#"?Y0$0C^`,$(WE!B"@X0(0H.,%`*#A"$"-Y0"`C>4#,(_@Z+#-
MY53T_^N2___J&#"=Y02@D^4``%KC3___"@H`H.$%]/_K`P!0XTO__YJL$)_E
M!`!`X@``BN`!$(_@7O3_ZP``4.,*D*`!0___ZB'T_^N,`)_E``"/X&7]_^LT
M;@``:&\``!P!```@#P``R&T``-`/```,#P``!`\``.0-``#8#@``(`$``,@.
M``#L:P``&`X``-P-``!$#```A`P```0,``"H"P``,`X``%`-``!8#0``_`T`
M`&0+``#0"@``Q`L``"1I```X"P```$-!0TA%``","0``%`P``#`+``#@"@``
MS`H```'*H.-P0"WI#,!-X.@/C.54(I_E5#*?Y0(@C^`#,)+G"-!-X@`PD^4$
M,(WE`#"@XW!/'>XX,I_E.`*?Y0,PG^<-$*#A`U"4YP``C^!H,-7E:3#%Y;#X
M_^L``%#C`@``"@`PT.4Q`%/C90``"J[[_^L$,I_E`S"?YP-0E.?\$9_E!0"@
MX0,PH.,!(*#C`1"/X(7S_^L`4%#B#```"N`AG^40$)7E`B"?YP`0D>4"`)3G
MT"&?Y0(@C^"!\__K$#"5Y0`0D^4(,)'E`043XU<``!JT$9_E`S"@XP$0G^<!
M(*#C`0"4YZ01G^4!$(_@;O/_ZP!04.(+```*E`&?Y0T0H.$``(_@A/C_ZQ`P
ME>4`(%#B`!"3Y3X```IX,9_E`S"?YP,`E.=F\__K;#&?Y6P1G^4#,)_G`2"@
MXP-0E.<!$(_@!0"@X4GS_^M4(9_E`!"@X0(@C^`%`*#A6?/_ZP`@H.-`,9_E
M0`&?Y0,PG^<-$*#A`S"4YP``C^!I(,/E9OC_ZRA1G^4``%#C!5"/X`!`H.$(
M`(7E$0``"@<=H.,$`*#A(_/_ZP$P@.(1`%#C`0!3$R0``(KX()_EL#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQH``!H(T(WB<("]Z`0`E>6Q_?_K``!0
MXP!`H.$(`(7EY___&K@`G^4``(_@C//_ZP$PT.4``%/CFO__"I7__^J@,)_E
M`0"@X0,PC^`$,)/E`!"3Y>WW_^N]___JB#"?Y0,PG^<#`)3G8O/_ZZ+__^II
M\__K=""?Y0`PH.$"((_@!!"2Y6@`G^4$(*#A`!"1Y0``C^!R\__K\&8``!P!
M``#89P``7`@``*!G``#L"0``<&<``,@)```\9P``G`D``%P'``#X9@``Y&8`
M`$P)``!0"0``K&8``-P&````9P``3&4``*P(``!L9@``X&4``#AF``!H"```
M`<J@XQ!`+>D,P$W@Z`^,Y1`AG^40,9_E`B"/X`!`H.$(`9_E$-!-X@,PDN<(
M$(WB``"/X``PD^4,,(WE`#"@XP+X_^L``%#C"@``"@`PT.4P`%/C``!3$P$P
MH`,`,*`3`3`CX@``5.,`,*`#`3`#$@``4^,*```:M""?Y:@PG^4"((_@`S"2
MYP`@D^4,,)WE`B`SX``PH.,A```:$-"-XA"`O>@`,-3E``!3X_'__PH$`*#A
M?/K_ZR\0H.,$`(WES_+_ZP0PG>4``%#C`3"`$@,`H.$&\__K6!"?Y00@H.,!
M$(_@,O/_ZP``4./A__\:1""?Y3`PG^4"((_@`S"2YP`@D^4,,)WE`B`SX``P
MH.,#```:!`"@X1#0C>(00+WHP_C_ZO[R_^LD9```'`$``,0%``"\8P``W`4`
M`$1C```!RJ#C$$`MZ0S`3>#X#XSE@`"@X^_R_^M0,(_BT"##X0`0H./P(,#A
M2#"/XM`@P^'X(,#A1#"/XM`@P^'P(<#A0#"/XM`@P^'X(<#A/#"/XM`@P^'P
M(L#A`""@XP`PH.-X$(#E^"+`X?`CP.$0@+WH`2-%9P````")J\WO`````/[<
MNI@`````=E0R$`````#PX=+#``````'*H./P1RWI#,!-X.`/C.4"8*#A`#"@
MXP!0H.$HX)#E+`"0Y8;!CN`.`%SA``#3X`%PH.$P()7E-!"5Y<8/H.$!```J
M`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@H!ZAX'@`E>4HP(7E``!0XS`PA>4T
M$(7E.*"%`B0``!H_`%;C'```V@=`H.$F@Z#A`9!(X@B#A^`$,*#A"@"@X4`@
MA.(`0)/E!."3Y0C`D^4,$)/E$#"#X@(`4^$`0(#E!."`Y0C`@.4,$(#E$`"`
MXO/__QH#0*#A!0"@X?+S_^L(`%3AZ___&D!PA^)`8$;B"7.'X`F=:>`)8X;@
M!B"@X0<0H.$*`*#A;_+_ZWA@A>7PA[WH0$!@X@8`5.$&0*"A.*"%X@<0H.$$
M(*#A``"*X&7R_^MX,)7E`S"$X$``4^-X,(7E\(>]&`4`H.$$8$;@!'"'X-3S
M_^O(___J`<J@X_!!+>D,P$W@Z`^,Y0%`H.%_$.#C*#"4Y3!@E.4S?[_FHS&@
MX3\P`^(!((/B.("$XC@`4N,`4*#A-F^_Y@,0R.<"`(C@.P``V@`0H.-`(&+B
M&/+_ZP0`H.&[\__K.""@XP`0H.,(`*#A$O+_ZP0`H.'P9\3AM//_ZP,PU.4$
M`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HP
MU.$%,,7E"#"4Y2,TH.$&,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4
MY2,TH.$*,,7E$#"4Y0LPQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E
M&#"4Y0\PQ>4C,-3E$##%Y;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P
M0;WH[O'_Z@`0H.,X(&+BW/'_Z\C__^H(,)_E`S"/X``PD^4T\O_J]&````A`
M+>D(@+WH`0`"`$`````)````,`````D````$````"0````P````)````/P``
M``D````W````"0```!<````)````+P````D````1````"0```#,````)````
M%0````D````2````"0```!\````)````-@````D````0````"0```"0````)
M````*@````D``````````````"]P<F]C+W-E;&8O97AE```E<R\E<P```$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/
M5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'
M3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!0
M15),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/
M0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```&QS965K
M(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```
M``!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L
M`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V-````%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,
M15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!
M4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T
M.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE0
M7TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI[
M"FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ
M*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O
M<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X]
M(#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU
M;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I
M;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K
M("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R
M;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G
M+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B
M)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U
M:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U
M=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N
M9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<
M,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB
M*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#
M.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D
M(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U
M;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@
M1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&
M24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&
M2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@
M=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@
M1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H
M97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD
M9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M
M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA
M;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@
M)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)
M3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@
M.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@
M("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z
M("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M
M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@
M(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^
M.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K
M?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I
M='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO
M861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C
M:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*
M?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T
M<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE
M(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H
M<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F
M:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E
M;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B
M.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H
M)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A
M<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M
M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C
M:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E
M:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L
M(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE
M.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB
M7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%2
M7TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T
M<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@
M86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO
M=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E
M<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I
M9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@
M*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E
M9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER
M92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?
M<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U
M<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<
M7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D
M<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C
M:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ
M<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA
M;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC
M*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O
M9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR
M96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S
M:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U
M9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*
M8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@
M(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]
M("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT
M96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O
M)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@
M/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L
M("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S
M92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D
M(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*
M<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N
M86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE
M('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P
M<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H
M)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]
M("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]
M("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@
M/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O
M9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y
M<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B
M?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%
M3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T
M<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]
M*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E
M='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`
M7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC
M('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS
M:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?
M87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@
M(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL
M97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q
M*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@
M)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`%5315(`
M````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!P97)L>'-I+F,`
M````0T%#2$4``$`````)````,`````D````$````"0````P````)````/P``
M``D````W````"0```!<````)````+P````D````1````"0```#,````)````
M%0````D````2````"0```!\````)````-@````D````0````"0```"0````)
M````*@````D``````````````(2R`8&PL*L'`````(>R`8&PL*H/`````*"R
M`8&PL*\'`````(.R`8&PL*@'`````(0"`8&P#[$``````(:R`8&PL*U_````
M`&"'_W^PJ0J`+(K_?P$```"8B_]_KRRR@"B8_W^<__]_6)G_?["PKH`LFO]_
ML*T$@'R<_W^PJ!N`))W_?["J'X"XGO]_L*@#@%R?_W^PL`&`K)__?W#__W_`
MH/]_L+"P@+R@_W]L__]_/*/_?["PJ(!DH_]_:/__?Q"E_W^PJ@&`2*K_?P"$
M`H#@JO]_7/__?TRK_W]@__]_!*W_?["PJ(`@K?]_L*H'@&2N_W^PKSR`K+7_
M?["J`8!PN/]_L*@#@*BY_W^PL*B`.+K_?["PKH"(N_]_L+"L@,R\_W^PL+"`
MV+S_?P$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````!!T``)`<```!
M````2P,```$```!6`P```0```&`#```!````=`,``!T```#\!```#````-`5
M```-````&$\``!D```"DK0``&P````0````:````J*T``!P````$````!```
M`+0!``#U_O]O[`0```4```"(#```!@```-@%```*````-P4```L````0````
M%0`````````#````S*X```(```#@`0``%````!$````7````\!,``!$````8
M$P``$@```-@````3````"````!X````(````^___;P$```C^__]OF!(``/__
M_V\#````\/__;\`1``#Z__]O#@``````````````````````````````````
M``````````````````````"LK0````````````#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<
M%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5
M``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4`
M`-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5````
M````````````````````````````````````````````````````````````
M````````P!@````````$L```"E!!4BYP;0H`````;)```!!0````````T%``
M`-10``!@D```&%```&B0````````3)```%20````````W%(``$=#0SH@*%-5
M4T4@3&EN=7@I(#$U+C$N,2`R,#(U,#8R-@!!,@```&%E86)I``$H````!39+
M6@`&!P@!"0$*`A($$P$4`14!%P,8`1D!&@(<`2(!1`$`+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N05)-+F5X=&%B`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y
M`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N
M=``N05)-+F%T=')I8G5T97,`````````````````````````````````````
M``````````````````````L````!`````@```%0!``!4`0``&0``````````
M`````0`````````3````!P````(```!P`0``<`$``"0```````````````0`
M````````)@````<````"````E`$``)0!```@```````````````$````````
M`#@````%`````@```+0!``"T`0``.`,```8`````````!`````0````T````
M]O__;P(```#L!```[`0``.P````&``````````0````$````/@````L````"
M````V`4``-@%``"P!@``!P````,````$````$````$8````#`````@```(@,
M``"(#```-P4``````````````0````````!.````____;P(```#`$0``P!$`
M`-8````&``````````(````"````6P```/[__V\"````F!(``)@2``"`````
M!P````,````$`````````&H````)`````@```!@3```8$P``V`````8`````
M````!`````@```!S````"0```$(```#P$P``\!,``.`!```&````%P````0`
M```(````?`````$````&````T!4``-`5```,```````````````$````````
M`'<````!````!@```-P5``#<%0``Y`(`````````````!`````0```""````
M`0````8```#`&```P!@``%@V``````````````@`````````B`````$````&
M````&$\``!A/```(```````````````$`````````(X````!`````@```"!/
M```@3P``^$$`````````````!`````````"6`````0````(````8D0``&)$`
M`$@```````````````0`````````H0````$``'""````8)$``&"1``#H````
M#@`````````$`````````*P````!`````@```$B2``!(D@``!```````````
M````!`````````"V````#@````,```"DK0``I)T```0```````````````0`
M```$````P@````\````#````J*T``*B=```$```````````````$````!```
M`,X````&`````P```*RM``"LG0``(`$```<`````````!`````@```#7````
M`0````,```#,K@``S)X``#0!``````````````0````$````W`````$````#
M`````+````"@``!(```````````````$`````````.(````(`````P```$BP
M``!(H```%```````````````!`````````#G`````0```#``````````2*``
M`"(```````````````$````!````\`````,``'```````````&J@```S````
M```````````!``````````$````#``````````````"=H`````$`````````
+`````0``````````
